#ifndef OPERATIONMODETOGGLER_H_
#define OPERATIONMODETOGGLER_H_

#include "DeviceManager.h"

#include <QThread>

class StartupSettings;
class AlarmSender;
class DeviceConfigurator;
class DeviceDataStorage;

class OperationModeToggler : public QThread
{
	Q_OBJECT
	
public:
	//! Constructor.
	/*!
	 * Constructor for HWKeyListener class
	 */
	OperationModeToggler( 
			DeviceManager::OperationMode aMode, 
			StartupSettings *aSettings, 
			AlarmSender *aAlarmSender, 
			DeviceConfigurator *aConfigurator, 
			DeviceDataStorage *aDataStorage 
			);
	
	//! Destructor.
	virtual ~OperationModeToggler();
	//! Run method of the class.
	/*!
	 * Run method of the class.
	 */
	void run();
	//! Returns the success status of the operation mode change.
	/*!
	 * Returns the success status of the operation mode change.
	 */
	bool success();
	//! Stores the current operation mode.
	/*!
	 * Stores the current operation mode by asking the DeviceDataStorage to write it to the internal
	 * data storage.
	 * \param aMode The operation mode that user wants to activate.
	 * \return True if operation mode storing succeeds; otherwise, false.
	 */
	static bool storeOperationMode( DeviceManager::OperationMode aMode, DeviceDataStorage *aDataStorage );

signals:
	//! Signal. Emitted if an error happens.
	/*!
	 * Signal. Emitted if an error happens.
	 * \param aCode An error code defined by DeviceManager.
	 * \param aAddInfo Possible additional information.
	 */
	void error( DeviceManager::ErrorCode aCode, const QString &aAddInfo );
	//! Signal. Emitted if an error occurs during operation mode changing.
	/*!
	 * Signal. Emitted if an error occurs during operation mode changing. If an error occurs, the operation
	 * mode changes made so far have to be rolled back. During this we don't want to show possible new
	 * errors. 
	 * \param aToggle Indicates if the errors are wanted to be shown.
	 */
	void toggleErrorSending( bool aToggle );
	//! Signal. Emitted during the operation mode change to explain the current sub-change.
	/*!
	 * Signal. Emitted during the operation mode change to explain the current sub-change. 
	 * \param aMessage Explains the sub-change
	 */
	void changingMode( const QString &aMessage );

private slots:
	//! Slot. Emits an error signal.
	/*!
	 * Slot. Emits an error signal. 
	 * \param aCode The error code.
	 */
	void createError( DeviceManager::ErrorCode aCode );
	
private:
	DeviceManager::OperationMode iMode;
	StartupSettings *iSettings;
	AlarmSender *iAlarmSender;
	DeviceConfigurator *iConfigurator;
	DeviceDataStorage *iDataStorage;
	bool iSuccess; 
};

#endif /*OPERATIONMODETOGGLER_H_*/
