#ifndef PASSWORDDIALOG_H_
#define PASSWORDDIALOG_H_

#include <QDialog>

class QLineEdit;
class QLabel;
class QByteArray;

//! UserInterface class. Responsible for poping-up password query on the screen.
/*!
 * UserInterface class. Responsible for poping-up password query on the screen. The class is used
 * through static method, just like the QMessageBox in the standard Qt library.
 */
class PasswordDialog : public QDialog
{
	Q_OBJECT

public:
	//! Enumeration of password authenticity.
	/*!
	 * Password authenticity.
	 */
	enum PasswordStatus
	{
		Correct, /*!< Correct password. */
		Incorrect, /*!< Incorrect password. */
		Canceled
	};
	
	//! Constructor.
	/*!
	 * Constructor to initialize a PasswordDialog instance.
	 * \param aParent The parent object.
	 * \param aPassword The password.
	 */
	PasswordDialog( const QString &aPassword, const QString &aText, const QString &aTitle = "", QWidget *aParent = 0 );
	//! Destructor.
	virtual ~PasswordDialog();
	//! Updates the text of the password dialog label.
	/*!
	 * Updates the text of the password dialog label.
	 * \param aText The text for the label.
	 */
	void update( const QString &aText );

signals:
	//! Signals the authenticity of the password when the uuser dismisses the dialog.
	/*!
	 * The signal is emitted if user presses a key available for the dialog.
	 * \param aStatus Password authenticity.
	 */
	void passwordEntered( PasswordDialog::PasswordStatus aStatus );

private slots:
	void okButtonPressed();
	void cancelButtonPressed();

private:
	QLineEdit *iPasswordEdit;
	QLabel *iText;
	QByteArray iPasswordHash;
};

#endif /*PASSWORDDIALOG_H_*/
